@@ -4,9 +4,6 @@ cdf_helpers.py
 High level functionality built on top of Cognite's Python SDK
 
 Most functions require the global cdf client to be set up before using them.
-
-Files handling functions work on an `mlops` folder. This is hard-coded,
-but it can be easily modified.
 """
 import time
 import os 
@@ -15,20 +12,14 @@ from shutil import make_archive, unpack_archive
 
 from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 
-from akerbp.mlops.core import logger 
+from akerbp.mlops.core import logger, config
+locals().update(config.getenv.__dict__)
 
 logging=logger.get_logger(name='cdf_helper')
 
 global_client = {}
+api_keys=config.api_keys.__dict__
 
-api_keys = dict(
-    functions = os.getenv('COGNITE_API_KEY_FUNCTIONS'),
-    data = os.getenv('COGNITE_API_KEY_DATA'),
-    files = os.getenv('COGNITE_API_KEY_FILES')
-)
-
-SERVICE_NAME = os.getenv("SERVICE_NAME")
-ENV=os.getenv("ENV")
 
 def set_up_cdf_client(context='run'):
     """
@@ -97,7 +88,6 @@ def create_function(
         logging.debug(f"Deleted function {function_name}")
     except CogniteNotFoundError:
         pass
-    env_vars = dict(SERVICE_NAME=SERVICE_NAME, ENV=ENV)
     function = client.functions.create( 
         name=function_name, 
         folder=folder, 
@@ -106,10 +96,10 @@ def create_function(
         description=description,
         owner=owner,
         secrets=secrets,
-        env_vars=env_vars
+        env_vars=config.getenv.__dict__
     )
     logging.debug(
-        f"Created {function_name}: {folder=}, {handler_path=}, {env_vars=}"
+        f"Created {function_name}: {folder=}, {handler_path=}"
     )
 
     return function
