@@ -6,21 +6,22 @@ from importlib import resources as importlib_resources
 import shutil
 import subprocess
 
-from akerbp.mlops.core import logger 
+from akerbp.mlops.core import logger, config 
 
 
 logging=logger.get_logger(name='MLOps')
 
-ENV = os.environ['ENV']
+locals().update(config.getenv.__dict__)
+
 
 def get_version():
     tag = subprocess.check_output(
         ['git', 'describe', '--tags', '--abbrev=0'],
         encoding='UTF-8'
     ).rstrip()
-    if ENV in ['dev', 'test']:
+    if env in ['dev', 'test']:
         version = '0.' + tag
-    elif ENV == 'prod':
+    elif env == 'prod':
         version = '1.' + tag
     return version
 
@@ -53,33 +54,6 @@ def set_mlops_import(req_file):
     logging.info(f"Set akerbp.mlops=={package_version} in requirements.txt")
 
 
-def read_config():
-    logging.info(f"Read project configuration")
-    from mlops_settings import model_names, model_files, model_req_files
-    from mlops_settings import model_artifact_folders, infos, model_test_files
-    from mlops_settings import model_platforms
-    return zip(
-        model_names, 
-        model_files, 
-        model_req_files, 
-        model_artifact_folders,
-        infos,
-        model_test_files,
-        model_platforms
-    )
-
-
-def get_top_folder(s):
-    return s.split(os.sep)[0]
-
-
-def as_import_path(file_path):
-    if file_path:
-        return file_path.replace(os.sep,'.').replace('.py','')
-    else:
-        logging.debug(f"Empty file path -> empty import path returned")
-
-
 def to_folder(path, folder_path):
     """
     Copy folders, files or package data to a given folder
@@ -107,6 +81,16 @@ def to_folder(path, folder_path):
         raise ValueError(f"{path} should be a file, folder or package resource")
 
 
+def copy_to_deployment_folder(files, deployment_folder):
+    """
+    Copy a list of files to a deployment folder
+    List of files is given as a dictionary where the key is the nick name of the file (will be used for logging) and the value is the path.
+    """
+    for k,v in files.items():
+        logging.debug(f"{k} => deployment folder")
+        to_folder(v, deployment_folder)
+
+
 def run_tests(test_path, path_type='file'):
     """
     Run tests with pytest
@@ -132,4 +116,18 @@ def run_tests(test_path, path_type='file'):
 def install_requirements(req_file):
     logging.info(f"Install python requirement file {req_file}")
     c = ["pip", "install", "--quiet", "-r", req_file]
-    subprocess.check_call(c)
\ No newline at end of file
+    subprocess.check_call(c)
+
+
+def set_up_requirements(model_req_file):
+    """
+    Set up a "requirements.txt" file at the top of the deployment folder
+    (assumed to be the current directory) and install dependencies (unless in
+    dev)
+    """
+    logging.info("Create requirement file")
+    if "akerbp/mlops" in get_repo_origin():
+        set_mlops_import(model_req_file)
+    shutil.move(model_req_file, 'requirements.txt')
+    if env != "dev":
+        install_requirements('requirements.txt')
