@@ -13,13 +13,10 @@ import requests
 import json
 
 
-from akerbp.mlops.core import logger 
-
+from akerbp.mlops.core import config, logger 
+locals().update(config.getenv.__dict__)
 logging=logger.get_logger(name='gc_helper')
 
-GOOGLE_PROJECT_ID = os.getenv("GOOGLE_PROJECT_ID")
-SERVICE_NAME = os.getenv("SERVICE_NAME")
-ENV = os.getenv("ENV")
 
 
 def create_service_account(service_account):
@@ -52,7 +49,7 @@ def access_secret_version(secret_id, version_id="latest"):
     client = secretmanager.SecretManagerServiceClient()
     # Build the resource name of the secret version.
     name = (
-      f"projects/{GOOGLE_PROJECT_ID}/secrets/{secret_id}/versions/{version_id}"
+      f"projects/{google_project_id}/secrets/{secret_id}/versions/{version_id}"
     )
     # Access the secret version.
     response = client.access_secret_version(name=name)
@@ -67,7 +64,7 @@ def create_image(image_name, folder='.'):
     logging.info(f"Build image {image_name} from {folder=}")
     subprocess.check_call(
         (f"gcloud builds submit {folder} "
-         f"--tag gcr.io/{GOOGLE_PROJECT_ID}/{image_name} "
+         f"--tag gcr.io/{google_project_id}/{image_name} "
           "--quiet"
         ), shell=True)
 
@@ -76,7 +73,7 @@ def allow_access_to_secrets(service_account, secret_names=["mlops-cdf-keys"]):
     """
     Give a service account access to secrets stored in Secret Manager
     """
-    s_a_id = f"{service_account}@{GOOGLE_PROJECT_ID}.iam.gserviceaccount.com"
+    s_a_id = f"{service_account}@{google_project_id}.iam.gserviceaccount.com"
     logging.debug(f"Give {service_account} access to {secret_names}")
     for secret_name in secret_names:
         subprocess.check_call(
@@ -92,13 +89,13 @@ def run_container(image_name, service_account):
     Run container with a service account
     """
     logging.info(f"Run container, {image_name=}, {service_account=}")
-    envs = ["GOOGLE_PROJECT_ID", "SERVICE_NAME", "ENV"]
+    envs = config.getenv.__dict__.keys()
     envs = [f"{env}={eval(env)}" for env in envs]
     env_list_string=','.join(envs)
     
     subprocess.check_call(
         (f"gcloud run deploy {image_name} "
-         f"--image gcr.io/{GOOGLE_PROJECT_ID}/{image_name} "
+         f"--image gcr.io/{google_project_id}/{image_name} "
           "--platform managed "
           "--region=europe-north1 "
           "--allow-unauthenticated " #"--no-allow-unauthenticated "
@@ -149,7 +146,7 @@ def call_function(function_name, data):
     """
     logging.debug(f"{data=}")
     url = read_function_url(function_name)
-    url+=f"/{SERVICE_NAME}"
+    url+=f"/{service_name}"
     logging.debug(f"Post to {url}")
     response = requests.post(url, json={'data': json.dumps(data)})
     logging.debug(f"Status: {response.status_code}")
