@@ -2,14 +2,11 @@
 
 import os
 
-from akerbp.mlops.core import logger
 import akerbp.mlops.cdf.helpers as cdf
-
-
-
+from akerbp.mlops.core import config, logger
+locals().update(config.getenv.__dict__)
 logging=logger.get_logger(name='MLOps')
 
-ENV = os.environ['ENV']
 
 
 def setup(cdf_api_keys=None):
@@ -126,14 +123,14 @@ def set_up_model_artifact(artifact_folder, model_name):
         value (existing folder in dev) or None (training service)
     """
     if os.path.isdir(artifact_folder):
-        if ENV=='dev':
+        if env=='dev':
             logging.info(f"Use model artifacts in {artifact_folder=}")
             model_id=f'{model_name}/dev/1'
             return model_id
         else:
-            message = f"Existing artifacts won't be used ({ENV=})"
+            message = f"Existing artifacts won't be used ({env=})"
             logging.warning(message)
     logging.info("Download serialized model")
-    model_id = download_model_version(model_name, ENV, artifact_folder)
+    model_id = download_model_version(model_name, env, artifact_folder)
 
     return model_id
\ No newline at end of file
