@@ -15,14 +15,13 @@ ModelException = model_module.ModelException
 
 import akerbp.mlops.model_manager as mm
 from akerbp.mlops import __version__ as version
-from akerbp.mlops.core import logger 
+from akerbp.mlops.core import config, logger 
+locals().update(config.getenv.__dict__)
 
 logging=logger.get_logger()
 
 logging.debug(f"MLOps framework version {version}")
 
-ENV = os.getenv('ENV')
-
 
 def _saver(path, metadata, cdf_api_keys):
     """
@@ -32,7 +31,7 @@ def _saver(path, metadata, cdf_api_keys):
     mm.setup(cdf_api_keys)
     model_info = mm.upload_new_model_version(
         model_name, 
-        ENV,  
+        env,  
         path,
         metadata
     )
